
#import "LDApp.h"

@interface LDApp ()

-(void)observeLogout:(NSNotification*)notification;

-(BOOL)executeScript:(id)sender;

@end

@implementation LDApp

-(void)applicationDidFinishLaunching:(NSNotification *)aNotification
{
    
    NSDistributedNotificationCenter *distributedNotificationCenter = [NSDistributedNotificationCenter defaultCenter];
    
    SEL observeLogoutAction = @selector(observeLogout:);
    
    [distributedNotificationCenter addObserver:self
                                      selector:observeLogoutAction
                                          name:@"com.apple.restartInitiated"
                                        object:nil];
    
    [distributedNotificationCenter addObserver:self
                                      selector:observeLogoutAction
                                          name:@"com.apple.shutdownInitiated"
                                        object:nil];
    
    [distributedNotificationCenter addObserver:self
                                      selector:observeLogoutAction
                                          name:@"com.apple.logoutInitiated"
                                        object:nil];
    
}

-(void)applicationWillTerminate:(NSNotification *)notification
{

    [[NSDistributedNotificationCenter defaultCenter] removeObserver:self];

}

-(void)observeLogout:(NSNotification*)notification
{
        
    [self executeScript:self];

}

-(BOOL)executeScript:(id)sender;
{

    NSString *scriptPath = [[NSBundle mainBundle] pathForResource:@"LogoutInitiatedAction"
                                                           ofType:@"scpt"];
    
    if([scriptPath length] < 1)
    {
        
        return NO;
        
    }
    
    NSURL *scriptURL = [NSURL fileURLWithPath:scriptPath];
    
    if(!scriptURL)
    {
        
        return NO;
        
    }
    
    NSDictionary *errors = nil;
    
    NSAppleScript *appleScript = [[NSAppleScript alloc] initWithContentsOfURL:scriptURL
                                                                        error:&errors];
    
    if(!appleScript)
    {
    
        return NO;
        
    }
    
    NSAppleEventDescriptor *appleScriptResult = [appleScript executeAndReturnError:&errors];
    
    if(!appleScriptResult)
    {
    
        return NO;
    
    }
    
    return YES;

}

@end